function [Tmse, Tcorr, Tpress] = KfoldCV_OSELM_ZeroMeanUnitVar(X, Y, k, ntry, nHL_interval, ActivationFunction)
  warning off;
  minNHL = nHL_interval(1,1);
  maxNHL = nHL_interval(1,2);
  CVO = cvpartition(Y,'k',k);
  
  %maximum number of neurons
  initNHL = inf;
  for  i = 1:k
        trIdx  = CVO.training(i);
        dOutTr = Y(trIdx,:); 
        acNHL  = size(dOutTr,1);
        if acNHL < initNHL
            initNHL = acNHL;
        end
  end
  if maxNHL > initNHL
     maxNHL = initNHL;   
  end 
  numberNHL = maxNHL - minNHL + 1;

  Tmse   = zeros(1,numberNHL);
  Tcorr  = zeros(1,numberNHL);
  Tpress = zeros(1,numberNHL);
  TmseTemp   = zeros(numberNHL,k);
  TcorrTemp  = zeros(numberNHL,k);
  TpressTemp = zeros(numberNHL,k);

  for n = 1:ntry
      for i = 1:k

            trIdx  = CVO.training(i);
            teIdx  = CVO.test(i);
            
            dOutTe = Y(teIdx,:); 
            dInTe  = X(teIdx,:); 

            dOutTr = Y(trIdx,:); 
            dInTr  = X(trIdx,:); 
            
            [mxcal, stdx, mycal, stdy, mcxcal, mcycal] = scaleZmean1Var(dInTr,dOutTr);
            scxtest = scale(dInTe, mxcal, stdx);          %center test X-block
            
            for nHL = minNHL:maxNHL
                [~, ~, ELM]       = OSELM_Reg_Train(mcxcal, mcycal, nHL, ActivationFunction);
                [~, yppred]       = OSELM_Reg_Test(scxtest, dOutTe, ELM);
                yppred            = rescale(yppred, mycal, stdy); %project and rescale predictions
                TmseTemp(nHL,i)   = mse(yppred - dOutTe);
                TcorrTemp(nHL,i)  = corr2(yppred, dOutTe);
                TpressTemp(nHL,i) = sum((yppred - dOutTe).^2);   
            end

      end
      
      for nHL = minNHL:maxNHL
             Tmse(1,nHL)   = mean(TmseTemp(nHL,:))   + Tmse(1,nHL); 
             Tcorr(1,nHL)  = mean(TcorrTemp(nHL,:))  + Tcorr(1,nHL);
             Tpress(1,nHL) = mean(TpressTemp(nHL,:)) + Tpress(1,nHL);
      end        
  end
  
  for nHL = minNHL:maxNHL
      Tmse(1,nHL)   = Tmse(1,nHL) / ntry; 
      Tcorr(1,nHL)  = Tcorr(1,nHL) / ntry;
      Tpress(1,nHL) = Tpress(1,nHL) / ntry;
  end
  

end